#
# Copyright (c) 2008-2016 Citrix Systems, Inc.
#
#   Licensed under the Apache License, Version 2.0 (the "License")
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#

from nssrc.com.citrix.netscaler.nitro.resource.base.base_resource import base_resource
from nssrc.com.citrix.netscaler.nitro.resource.base.base_resource import base_response
from nssrc.com.citrix.netscaler.nitro.service.options import options
from nssrc.com.citrix.netscaler.nitro.exception.nitro_exception import nitro_exception

from nssrc.com.citrix.netscaler.nitro.util.nitro_util import nitro_util

class pcpprofile(base_resource) :
	""" Configuration for PCP Profile resource. """
	def __init__(self) :
		self._name = None
		self._mapping = None
		self._peer = None
		self._minmaplife = None
		self._maxmaplife = None
		self._announcemulticount = None
		self._thirdparty = None
		self.___count = None

	@property
	def name(self) :
		r"""Name for the PCP Profile. Must begin with an ASCII alphanumeric or underscore (_) character, and must contain only ASCII alphanumeric, underscore CLI Users: If the name includes one or more spaces, enclose the name in double or single quotation marks (for example, "my pcpProfile" or my pcpProfile).
		"""
		try :
			return self._name
		except Exception as e:
			raise e

	@name.setter
	def name(self, name) :
		r"""Name for the PCP Profile. Must begin with an ASCII alphanumeric or underscore (_) character, and must contain only ASCII alphanumeric, underscore CLI Users: If the name includes one or more spaces, enclose the name in double or single quotation marks (for example, "my pcpProfile" or my pcpProfile).
		"""
		try :
			self._name = name
		except Exception as e:
			raise e

	@property
	def mapping(self) :
		r"""This argument is for enabling/disabling the MAP opcode  of current PCP Profile.<br/>Default value: ENABLED<br/>Possible values = ENABLED, DISABLED.
		"""
		try :
			return self._mapping
		except Exception as e:
			raise e

	@mapping.setter
	def mapping(self, mapping) :
		r"""This argument is for enabling/disabling the MAP opcode  of current PCP Profile.<br/>Default value: ENABLED<br/>Possible values = ENABLED, DISABLED
		"""
		try :
			self._mapping = mapping
		except Exception as e:
			raise e

	@property
	def peer(self) :
		r"""This argument is for enabling/disabling the PEER opcode of current PCP Profile.<br/>Default value: ENABLED<br/>Possible values = ENABLED, DISABLED.
		"""
		try :
			return self._peer
		except Exception as e:
			raise e

	@peer.setter
	def peer(self, peer) :
		r"""This argument is for enabling/disabling the PEER opcode of current PCP Profile.<br/>Default value: ENABLED<br/>Possible values = ENABLED, DISABLED
		"""
		try :
			self._peer = peer
		except Exception as e:
			raise e

	@property
	def minmaplife(self) :
		r"""Integer value that identify the minimum mapping lifetime (in seconds) for a pcp profile. default(120s).<br/>Maximum length =  2147483647.
		"""
		try :
			return self._minmaplife
		except Exception as e:
			raise e

	@minmaplife.setter
	def minmaplife(self, minmaplife) :
		r"""Integer value that identify the minimum mapping lifetime (in seconds) for a pcp profile. default(120s).<br/>Maximum length =  2147483647
		"""
		try :
			self._minmaplife = minmaplife
		except Exception as e:
			raise e

	@property
	def maxmaplife(self) :
		r"""Integer value that identify the maximum mapping lifetime (in seconds) for a pcp profile. default(86400s = 24Hours).<br/>Maximum length =  2147483647.
		"""
		try :
			return self._maxmaplife
		except Exception as e:
			raise e

	@maxmaplife.setter
	def maxmaplife(self, maxmaplife) :
		r"""Integer value that identify the maximum mapping lifetime (in seconds) for a pcp profile. default(86400s = 24Hours).<br/>Maximum length =  2147483647
		"""
		try :
			self._maxmaplife = maxmaplife
		except Exception as e:
			raise e

	@property
	def announcemulticount(self) :
		r"""Integer value that identify the number announce message to be send.<br/>Default value: 10<br/>Maximum length =  65535.
		"""
		try :
			return self._announcemulticount
		except Exception as e:
			raise e

	@announcemulticount.setter
	def announcemulticount(self, announcemulticount) :
		r"""Integer value that identify the number announce message to be send.<br/>Default value: 10<br/>Maximum length =  65535
		"""
		try :
			self._announcemulticount = announcemulticount
		except Exception as e:
			raise e

	@property
	def thirdparty(self) :
		r"""This argument is for enabling/disabling the THIRD PARTY opcode of current PCP Profile.<br/>Default value: DISABLED<br/>Possible values = ENABLED, DISABLED.
		"""
		try :
			return self._thirdparty
		except Exception as e:
			raise e

	@thirdparty.setter
	def thirdparty(self, thirdparty) :
		r"""This argument is for enabling/disabling the THIRD PARTY opcode of current PCP Profile.<br/>Default value: DISABLED<br/>Possible values = ENABLED, DISABLED
		"""
		try :
			self._thirdparty = thirdparty
		except Exception as e:
			raise e

	def _get_nitro_response(self, service, response) :
		r""" converts nitro response into object and returns the object array in case of get request.
		"""
		try :
			result = service.payload_formatter.string_to_resource(pcpprofile_response, response, self.__class__.__name__)
			if(result.errorcode != 0) :
				if (result.errorcode == 444) :
					service.clear_session(self)
				if result.severity :
					if (result.severity == "ERROR") :
						raise nitro_exception(result.errorcode, str(result.message), str(result.severity))
				else :
					raise nitro_exception(result.errorcode, str(result.message), str(result.severity))
			return result.pcpprofile
		except Exception as e :
			raise e

	def _get_object_name(self) :
		r""" Returns the value of object identifier argument
		"""
		try :
			if self.name is not None :
				return str(self.name)
			return None
		except Exception as e :
			raise e



	@classmethod
	def add(cls, client, resource) :
		r""" Use this API to add pcpprofile.
		"""
		try :
			if type(resource) is not list :
				addresource = pcpprofile()
				addresource.name = resource.name
				addresource.mapping = resource.mapping
				addresource.peer = resource.peer
				addresource.minmaplife = resource.minmaplife
				addresource.maxmaplife = resource.maxmaplife
				addresource.announcemulticount = resource.announcemulticount
				addresource.thirdparty = resource.thirdparty
				return addresource.add_resource(client)
			else :
				if (resource and len(resource) > 0) :
					addresources = [ pcpprofile() for _ in range(len(resource))]
					for i in range(len(resource)) :
						addresources[i].name = resource[i].name
						addresources[i].mapping = resource[i].mapping
						addresources[i].peer = resource[i].peer
						addresources[i].minmaplife = resource[i].minmaplife
						addresources[i].maxmaplife = resource[i].maxmaplife
						addresources[i].announcemulticount = resource[i].announcemulticount
						addresources[i].thirdparty = resource[i].thirdparty
				result = cls.add_bulk_request(client, addresources)
			return result
		except Exception as e :
			raise e

	@classmethod
	def delete(cls, client, resource) :
		r""" Use this API to delete pcpprofile.
		"""
		try :
			if type(resource) is not list :
				deleteresource = pcpprofile()
				if type(resource) !=  type(deleteresource):
					deleteresource.name = resource
				else :
					deleteresource.name = resource.name
				return deleteresource.delete_resource(client)
			else :
				if type(resource[0]) != cls :
					if (resource and len(resource) > 0) :
						deleteresources = [ pcpprofile() for _ in range(len(resource))]
						for i in range(len(resource)) :
							deleteresources[i].name = resource[i]
				else :
					if (resource and len(resource) > 0) :
						deleteresources = [ pcpprofile() for _ in range(len(resource))]
						for i in range(len(resource)) :
							deleteresources[i].name = resource[i].name
				result = cls.delete_bulk_request(client, deleteresources)
			return result
		except Exception as e :
			raise e

	@classmethod
	def update(cls, client, resource) :
		r""" Use this API to update pcpprofile.
		"""
		try :
			if type(resource) is not list :
				updateresource = pcpprofile()
				updateresource.name = resource.name
				updateresource.mapping = resource.mapping
				updateresource.peer = resource.peer
				updateresource.minmaplife = resource.minmaplife
				updateresource.maxmaplife = resource.maxmaplife
				updateresource.announcemulticount = resource.announcemulticount
				updateresource.thirdparty = resource.thirdparty
				return updateresource.update_resource(client)
			else :
				if (resource and len(resource) > 0) :
					updateresources = [ pcpprofile() for _ in range(len(resource))]
					for i in range(len(resource)) :
						updateresources[i].name = resource[i].name
						updateresources[i].mapping = resource[i].mapping
						updateresources[i].peer = resource[i].peer
						updateresources[i].minmaplife = resource[i].minmaplife
						updateresources[i].maxmaplife = resource[i].maxmaplife
						updateresources[i].announcemulticount = resource[i].announcemulticount
						updateresources[i].thirdparty = resource[i].thirdparty
				result = cls.update_bulk_request(client, updateresources)
			return result
		except Exception as e :
			raise e

	@classmethod
	def unset(cls, client, resource, args) :
		r""" Use this API to unset the properties of pcpprofile resource.
		Properties that need to be unset are specified in args array.
		"""
		try :
			if type(resource) is not list :
				unsetresource = pcpprofile()
				if type(resource) !=  type(unsetresource):
					unsetresource.name = resource
				else :
					unsetresource.name = resource.name
				return unsetresource.unset_resource(client, args)
			else :
				if type(resource[0]) != cls :
					if (resource and len(resource) > 0) :
						unsetresources = [ pcpprofile() for _ in range(len(resource))]
						for i in range(len(resource)) :
							unsetresources[i].name = resource[i]
				else :
					if (resource and len(resource) > 0) :
						unsetresources = [ pcpprofile() for _ in range(len(resource))]
						for i in range(len(resource)) :
							unsetresources[i].name = resource[i].name
				result = cls.unset_bulk_request(client, unsetresources, args)
			return result
		except Exception as e :
			raise e

	@classmethod
	def get(cls, client, name="", option_="") :
		r""" Use this API to fetch all the pcpprofile resources that are configured on netscaler.
		"""
		try :
			if not name :
				obj = pcpprofile()
				response = obj.get_resources(client, option_)
			else :
				if type(name) != cls :
					if type(name) is not list :
						obj = pcpprofile()
						obj.name = name
						response = obj.get_resource(client, option_)
					else :
						if name and len(name) > 0 :
							response = [pcpprofile() for _ in range(len(name))]
							obj = [pcpprofile() for _ in range(len(name))]
							for i in range(len(name)) :
								obj[i] = pcpprofile()
								obj[i].name = name[i]
								response[i] = obj[i].get_resource(client, option_)
			return response
		except Exception as e :
			raise e


	@classmethod
	def get_filtered(cls, client, filter_) :
		r""" Use this API to fetch filtered set of pcpprofile resources.
		filter string should be in JSON format.eg: "port:80,servicetype:HTTP".
		"""
		try :
			obj = pcpprofile()
			option_ = options()
			option_.filter = filter_
			response = obj.getfiltered(client, option_)
			return response
		except Exception as e :
			raise e


	@classmethod
	def count(cls, client) :
		r""" Use this API to count the pcpprofile resources configured on NetScaler.
		"""
		try :
			obj = pcpprofile()
			option_ = options()
			option_.count = True
			response = obj.get_resources(client, option_)
			if response :
				return response[0].__dict__['___count']
			return 0
		except Exception as e :
			raise e

	@classmethod
	def count_filtered(cls, client, filter_) :
		r""" Use this API to count filtered the set of pcpprofile resources.
		Filter string should be in JSON format.eg: "port:80,servicetype:HTTP".
		"""
		try :
			obj = pcpprofile()
			option_ = options()
			option_.count = True
			option_.filter = filter_
			response = obj.getfiltered(client, option_)
			if response :
				return response[0].__dict__['___count']
			return 0
		except Exception as e :
			raise e


	class Mapping:
		ENABLED = "ENABLED"
		DISABLED = "DISABLED"

	class Thirdparty:
		ENABLED = "ENABLED"
		DISABLED = "DISABLED"

	class Peer:
		ENABLED = "ENABLED"
		DISABLED = "DISABLED"

class pcpprofile_response(base_response) :
	def __init__(self, length=1) :
		self.pcpprofile = []
		self.errorcode = 0
		self.message = ""
		self.severity = ""
		self.sessionid = ""
		self.pcpprofile = [pcpprofile() for _ in range(length)]

