#
# Copyright (c) 2008-2016 Citrix Systems, Inc.
#
#   Licensed under the Apache License, Version 2.0 (the "License")
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#

from nssrc.com.citrix.netscaler.nitro.resource.base.base_resource import base_resource
from nssrc.com.citrix.netscaler.nitro.resource.base.base_resource import base_response
from nssrc.com.citrix.netscaler.nitro.service.options import options
from nssrc.com.citrix.netscaler.nitro.exception.nitro_exception import nitro_exception

from nssrc.com.citrix.netscaler.nitro.util.nitro_util import nitro_util

class riseprofile_binding(base_resource):
	""" Binding class showing the resources that can be bound to riseprofile_binding. 
	"""
	def __init__(self) :
		self._profilename = None
		self.riseprofile_interface_binding = []

	@property
	def profilename(self) :
		r"""Name of the RISE profile.<br/>Minimum length =  1<br/>Maximum length =  83.
		"""
		try :
			return self._profilename
		except Exception as e:
			raise e

	@profilename.setter
	def profilename(self, profilename) :
		r"""Name of the RISE profile.<br/>Minimum length =  1<br/>Maximum length =  83
		"""
		try :
			self._profilename = profilename
		except Exception as e:
			raise e

	@property
	def riseprofile_interface_bindings(self) :
		r"""interface that can be bound to riseprofile.
		"""
		try :
			return self._riseprofile_interface_binding
		except Exception as e:
			raise e

	def _get_nitro_response(self, service, response) :
		r""" converts nitro response into object and returns the object array in case of get request.
		"""
		try :
			result = service.payload_formatter.string_to_resource(riseprofile_binding_response, response, self.__class__.__name__)
			if(result.errorcode != 0) :
				if (result.errorcode == 444) :
					service.clear_session(self)
				if result.severity :
					if (result.severity == "ERROR") :
						raise nitro_exception(result.errorcode, str(result.message), str(result.severity))
				else :
					raise nitro_exception(result.errorcode, str(result.message), str(result.severity))
			return result.riseprofile_binding
		except Exception as e :
			raise e

	def _get_object_name(self) :
		r""" Returns the value of object identifier argument
		"""
		try :
			if self.profilename is not None :
				return str(self.profilename)
			return None
		except Exception as e :
			raise e



	@classmethod
	def get(self, service, profilename="", option_="") :
		r""" Use this API to fetch riseprofile_binding resource.
		"""
		try :
			if not profilename :
				obj = riseprofile_binding()
				response = obj.get_resources(service, option_)
			elif type(profilename) is not list :
				obj = riseprofile_binding()
				obj.profilename = profilename
				response = obj.get_resource(service)
			else :
				if profilename and len(profilename) > 0 :
					obj = [riseprofile_binding() for _ in range(len(profilename))]
					for i in range(len(profilename)) :
						obj[i].profilename = profilename[i];
						response[i] = obj[i].get_resource(service)
			return response
		except Exception as e:
			raise e

class riseprofile_binding_response(base_response) :
	def __init__(self, length=1) :
		self.riseprofile_binding = []
		self.errorcode = 0
		self.message = ""
		self.severity = ""
		self.sessionid = ""
		self.riseprofile_binding = [riseprofile_binding() for _ in range(length)]

