#
# Copyright (c) 2008-2016 Citrix Systems, Inc.
#
#   Licensed under the Apache License, Version 2.0 (the "License")
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#

from nssrc.com.citrix.netscaler.nitro.resource.base.base_resource import base_resource
from nssrc.com.citrix.netscaler.nitro.resource.base.base_resource import base_response
from nssrc.com.citrix.netscaler.nitro.service.options import options
from nssrc.com.citrix.netscaler.nitro.exception.nitro_exception import nitro_exception

from nssrc.com.citrix.netscaler.nitro.util.nitro_util import nitro_util

class vpnglobal_intranetip6_binding(base_resource) :
	""" Binding class showing the intranetip6 that can be bound to vpnglobal.
	"""
	def __init__(self) :
		self._intranetip6 = None
		self._numaddr = None
		self.___count = None

	@property
	def intranetip6(self) :
		r"""The intranet ip address or range.
		"""
		try :
			return self._intranetip6
		except Exception as e:
			raise e

	@intranetip6.setter
	def intranetip6(self, intranetip6) :
		r"""The intranet ip address or range.
		"""
		try :
			self._intranetip6 = intranetip6
		except Exception as e:
			raise e

	@property
	def numaddr(self) :
		r"""The intranet ip address or range's netmask.
		"""
		try :
			return self._numaddr
		except Exception as e:
			raise e

	@numaddr.setter
	def numaddr(self, numaddr) :
		r"""The intranet ip address or range's netmask.
		"""
		try :
			self._numaddr = numaddr
		except Exception as e:
			raise e

	def _get_nitro_response(self, service, response) :
		r""" converts nitro response into object and returns the object array in case of get request.
		"""
		try :
			result = service.payload_formatter.string_to_resource(vpnglobal_intranetip6_binding_response, response, self.__class__.__name__)
			if(result.errorcode != 0) :
				if (result.errorcode == 444) :
					service.clear_session(self)
				if result.severity :
					if (result.severity == "ERROR") :
						raise nitro_exception(result.errorcode, str(result.message), str(result.severity))
				else :
					raise nitro_exception(result.errorcode, str(result.message), str(result.severity))
			return result.vpnglobal_intranetip6_binding
		except Exception as e :
			raise e

	def _get_object_name(self) :
		r""" Returns the value of object identifier argument
		"""
		try :
			return 0
		except Exception as e :
			raise e



	@classmethod
	def add(cls, client, resource) :
		try :
			if resource and type(resource) is not list :
				updateresource = vpnglobal_intranetip6_binding()
				updateresource.intranetip6 = resource.intranetip6
				updateresource.numaddr = resource.numaddr
				return updateresource.update_resource(client)
			else :
				if resource and len(resource) > 0 :
					updateresources = [vpnglobal_intranetip6_binding() for _ in range(len(resource))]
					for i in range(len(resource)) :
						updateresources[i].intranetip6 = resource[i].intranetip6
						updateresources[i].numaddr = resource[i].numaddr
				return cls.update_bulk_request(client, updateresources)
		except Exception as e :
			raise e

	@classmethod
	def delete(cls, client, resource) :
		try :
			if resource and type(resource) is not list :
				deleteresource = vpnglobal_intranetip6_binding()
				deleteresource.intranetip6 = resource.intranetip6
				deleteresource.numaddr = resource.numaddr
				return deleteresource.delete_resource(client)
			else :
				if resource and len(resource) > 0 :
					deleteresources = [vpnglobal_intranetip6_binding() for _ in range(len(resource))]
					for i in range(len(resource)) :
						deleteresources[i].intranetip6 = resource[i].intranetip6
						deleteresources[i].numaddr = resource[i].numaddr
				return cls.delete_bulk_request(client, deleteresources)
		except Exception as e :
			raise e

	@classmethod
	def get(cls, service) :
		r""" Use this API to fetch a vpnglobal_intranetip6_binding resources.
		"""
		try :
			obj = vpnglobal_intranetip6_binding()
			response = obj.get_resources(service)
			return response
		except Exception as e:
			raise e

	@classmethod
	def get_filtered(cls, service, filter_) :
		r""" Use this API to fetch filtered set of vpnglobal_intranetip6_binding resources.
		Filter string should be in JSON format.eg: "port:80,servicetype:HTTP".
		"""
		try :
			obj = vpnglobal_intranetip6_binding()
			option_ = options()
			option_.filter = filter_
			response = obj.getfiltered(service, option_)
			return response
		except Exception as e:
			raise e

	@classmethod
	def count(cls, service) :
		r""" Use this API to count vpnglobal_intranetip6_binding resources configued on NetScaler.
		"""
		try :
			obj = vpnglobal_intranetip6_binding()
			option_ = options()
			option_.count = True
			response = obj.get_resources(service, option_)
			if response :
				return response[0].__dict__['___count']
			return 0
		except Exception as e:
			raise e

	@classmethod
	def count_filtered(cls, service, filter_) :
		r""" Use this API to count the filtered set of vpnglobal_intranetip6_binding resources.
		Filter string should be in JSON format.eg: "port:80,servicetype:HTTP".
		"""
		try :
			obj = vpnglobal_intranetip6_binding()
			option_ = options()
			option_.count = True
			option_.filter = filter_
			response = obj.getfiltered(service, option_)
			if response :
				return response[0].__dict__['___count']
			return 0
		except Exception as e:
			raise e

class vpnglobal_intranetip6_binding_response(base_response) :
	def __init__(self, length=1) :
		self.vpnglobal_intranetip6_binding = []
		self.errorcode = 0
		self.message = ""
		self.severity = ""
		self.sessionid = ""
		self.vpnglobal_intranetip6_binding = [vpnglobal_intranetip6_binding() for _ in range(length)]

